@@ -1,3 +1,5 @@
+import codecs
+import csv
 import io
 import json
 from typing import Any
@@ -20,3 +22,8 @@ class Download(S3Base):
 
         except Exception as e:
             raise e
+
+    def download_csv(self, bucket: str, file_name: str) -> csv.DictReader:
+        s3_object = self.client.get_object(Bucket=bucket, Key=file_name)
+
+        return csv.DictReader(codecs.getreader("utf-8")(s3_object["Body"]))
