@@ -27,3 +27,7 @@ class S3Base:
     @property
     def resource(self):
         return self._resource.resource('s3')
+
+    @property
+    def client(self):
+        return boto3.client("s3")
