@@ -7,6 +7,7 @@ from aioredis import Redis, create_redis
 
 from komolibs.core.utils.async_utils import safe_ensure_future
 from komolibs.logger import KomoLogger
+from komolibs.pubsub import check_redis_connection_sync
 
 
 class Publisher:
@@ -94,3 +95,13 @@ class Publisher:
             raise
         finally:
             await self.stop()
+
+    def is_connection_ok(self):
+        try:
+            check_redis_connection_sync(url=self._url,
+                                        port=int(self._port),
+                                        password=self._password)
+            return True
+        except Exception as e:
+            self.logger().error(f"Redis connection error {e}")
+            return False
